'use strict';

Object.defineProperty(exports, '__esModule', {
    value: true
});

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _Pane = require('./Pane');

var _Pane2 = _interopRequireDefault(_Pane);

var _Resizer = require('./Resizer');

var _Resizer2 = _interopRequireDefault(_Resizer);

var _reactVendorPrefix = require('react-vendor-prefix');

var _reactVendorPrefix2 = _interopRequireDefault(_reactVendorPrefix);

var SplitPane = _react2['default'].createClass({
    displayName: 'SplitPane',

    propTypes: {
        minSize: _react2['default'].PropTypes.number,
        split: _react2['default'].PropTypes.string
    },

    getInitialState: function getInitialState() {
        return {
            active: false
        };
    },

    getDefaultProps: function getDefaultProps() {
        return {
            minSize: 0
        };
    },

    componentDidMount: function componentDidMount() {
        document.addEventListener('mouseup', this.up);
        document.addEventListener('mousemove', this.move);
    },

    componentWillUnmount: function componentWillUnmount() {
        document.removeEventListener('mouseup', this.up);
        document.removeEventListener('mousemove', this.move);
    },

    down: function down(event) {
        var position = this.props.split === 'vertical' ? event.clientX : event.clientY;
        this.setState({
            active: true,
            position: position
        });
    },

    move: function move(event) {
        if (this.state.active) {
            var ref = this.refs.pane1;
            if (ref) {
                var node = ref.getDOMNode();
                if (window.getComputedStyle) {
                    var styles = window.getComputedStyle(node);
                    var width = styles.width.replace('px', '');
                    var height = styles.height.replace('px', '');
                    var current = this.props.split === 'vertical' ? event.clientX : event.clientY;
                    var size = this.props.split === 'vertical' ? width : height;
                    var position = this.state.position;
                    var newSize = size - (position - current);
                    this.setState({
                        position: current
                    });
                    if (newSize >= this.props.minSize) {
                        ref.setState({
                            size: newSize
                        });
                    }
                }
            }
        }
    },

    up: function up() {
        this.setState({
            active: false
        });
    },

    merge: function merge(into, obj) {
        for (var attr in obj) {
            into[attr] = obj[attr];
        }
    },

    render: function render() {
        var split = this.props.split || 'vertical';

        var style = {
            display: 'flex',
            flex: 1,
            position: 'relative',
            outline: 'none',
            overflow: 'hidden',
            userSelect: 'none'
        };

        if (split === 'horizontal') {
            this.merge(style, {
                flexDirection: 'column',
                height: '100%',
                minHeight: '100%',
                position: 'absolute',
                top: 0,
                bottom: 0,
                width: '100%'
            });
        } else {
            this.merge(style, {
                flexDirection: 'row',
                height: '100%',
                position: 'absolute',
                left: 0,
                right: 0
            });
        }

        var elements = [];
        var children = this.props.children;
        var child0 = children[0];
        var child1 = children[1];
        elements.push(_react2['default'].createElement(
            _Pane2['default'],
            { ref: 'pane1', key: 'pane1', split: split },
            child0
        ));
        elements.push(_react2['default'].createElement(_Resizer2['default'], { ref: 'resizer', key: 'resizer', down: this.down, split: split }));
        elements.push(_react2['default'].createElement(
            _Pane2['default'],
            { ref: 'pane2', key: 'pane2', split: split },
            child1
        ));

        var classes = ['SplitPane', split];

        var prefixed = _reactVendorPrefix2['default'].prefix({ styles: style });

        return _react2['default'].createElement(
            'div',
            { className: classes.join(' '), style: prefixed.styles, ref: 'splitPane' },
            elements
        );
    }
});

exports['default'] = SplitPane;
module.exports = exports['default'];